@@ -1,11 +1,12 @@
 # encoding=UTF-8
-# Copyright © 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
@@ -18,6 +19,7 @@ import sys
 
 from .. import hocr
 from .. import ipc
+from .. import logger
 from .. import temporary
 from .. import text_zones
 from .. import unicode_support
@@ -32,6 +34,8 @@ __version__ = version.__version__
 
 system_encoding = locale.getpreferredencoding()
 
+logger = logger.setup()
+
 class ArgumentParser(argparse.ArgumentParser):
 
     def __init__(self):
@@ -278,7 +282,7 @@ hocr_footer = '''
 
 def main(argv=sys.argv):
     options = ArgumentParser().parse_args(argv[1:])
-    print >>sys.stderr, 'Converting %s:' % utils.smart_repr(options.path, system_encoding)
+    logger.info('Converting %s:' % utils.smart_repr(options.path, system_encoding))
     if options.pages is None:
         djvused = ipc.Subprocess(
             ['djvused', '-e', 'n', os.path.abspath(options.path)],
@@ -303,11 +307,7 @@ def main(argv=sys.argv):
             ocr_system='djvu2hocr %s' % __version__,
             ocr_capabilities=' '.join(hocr.djvu2hocr_capabilities)
     ))
-    while 1:
-        try:
-            n = page_iterator.next()
-        except StopIteration:
-            break
+    for n in page_iterator:
         try:
             page_size = [
                 int(str(sexpr.Expression.from_stream(djvused.stdout).value).split('=')[1])
@@ -317,7 +317,7 @@ def main(argv=sys.argv):
             page_text = sexpr.Expression.from_stream(djvused.stdout)
         except sexpr.ExpressionSyntaxError:
             break
-        print >>sys.stderr, '- Page #%d' % n
+        logger.info('- Page #%d', n)
         page_zone = Zone(page_text, page_size[1])
         process_page(page_zone, options)
     sys.stdout.write(hocr_footer)
