@@ -1,11 +1,12 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
@@ -25,6 +26,7 @@ import traceback
 from .. import engines
 from .. import errors
 from .. import ipc
+from .. import logger
 from .. import temporary
 from .. import text_zones
 from .. import utils
@@ -38,6 +40,8 @@ __version__ = version.__version__
 
 system_encoding = locale.getpreferredencoding()
 
+logger = logger.setup()
+
 class Saver(object):
 
     in_place = False
@@ -212,10 +216,10 @@ class ArgumentParser(argparse.ArgumentParser):
                 for language in namespace.engine().list_languages():
                     print language
             except errors.EngineNotFound, ex:
-                print >>sys.stderr, ex
+                logger.error(ex)
                 sys.exit(1)
             except errors.UnknownLanguageList, ex:
-                print >>sys.stderr, ex
+                logger.error(ex)
                 sys.exit(1)
             else:
                 sys.exit(0)
@@ -301,7 +305,7 @@ class Context(djvu.decode.Context):
 
     def handle_message(self, message):
         if isinstance(message, djvu.decode.ErrorMessage):
-            print >>sys.stderr, message
+            logger.warning(message)
             sys.exit(1)
 
     @contextlib.contextmanager
@@ -316,7 +320,7 @@ class Context(djvu.decode.Context):
             file.close()
 
     def process_page(self, page):
-        print >>sys.stderr, '- Page #%d' % (page.n + 1)
+        logger.info('- Page #%d', page.n + 1)
         page_job = page.decode(wait=True)
         size = page_job.size
         with self.get_output_image(page.n, page_job) as pfile:
@@ -356,7 +360,7 @@ class Context(djvu.decode.Context):
             try:
                 result = self.process_page(page)
             except djvu.decode.NotAvailable:
-                print >>sys.stderr, 'No image suitable for OCR.'
+                logger.info('No image suitable for OCR.')
                 result = False
             except (SystemExit, KeyboardInterrupt), ex:
                 with condition:
@@ -366,7 +370,7 @@ class Context(djvu.decode.Context):
                 try:
                     interrupted_by_user = isinstance(ex, ipc.CalledProcessInterrupted) and ex.by_user
                     message = 'Exception while processing page %d:\n%s' % (n + 1, traceback.format_exc())
-                    print >>sys.stderr, message.rstrip()
+                    logger.error(message.rstrip())
                     if self._options.resume_on_error and not interrupted_by_user:
                         # As requested by user, don't abort on error and pretend that nothing happened.
                         results[n] = False
@@ -385,7 +389,7 @@ class Context(djvu.decode.Context):
 
     def _process(self, path, pages=None):
         self._engine = self._options.engine
-        print >>sys.stderr, 'Processing %s:' % utils.smart_repr(path, system_encoding)
+        logger.info('Processing %s:', utils.smart_repr(path, system_encoding))
         document = self.new_document(djvu.decode.FileURI(path))
         document.decoding_job.wait()
         if pages is None:
@@ -398,6 +402,12 @@ class Context(djvu.decode.Context):
             threading.Thread(target=self.page_thread, args=(pages, results, condition))
             for i in xrange(self._options.n_jobs)
         ]
+        def stop_threads():
+            with condition:
+                for page in pages:
+                    # Worker threads should not bother with processing other pages.
+                    # Mark them as already taken.
+                    results[page.n] = True
         for thread in threads:
             thread.start()
         sed_file = self._temp_file('ocrodjvu.djvused', auto_remove=False)
@@ -408,19 +418,24 @@ class Context(djvu.decode.Context):
                 file_id = page.file.id.encode(system_encoding)
                 sed_file.write('select \'%s\'\n' % file_id.replace('\\', '\\\\').replace("'", "\\'"))
                 sed_file.write('set-txt\n')
+                result = None
                 with condition:
                     while 1:
                         result = results[page.n]
                         if result is None or result is True:
                             # Result is not yet available.
                             condition.wait()
-                        elif isinstance(result, Exception):
-                            for thread in threads:
-                                thread.join()
-                            self._debug = True
-                            sys.exit(1)
-                        else:
-                            break
+                            continue
+                        if isinstance(result, Exception):
+                            stop_threads()
+                        break
+                if isinstance(result, Exception):
+                    if len(threads) > 1:
+                        logger.info('Waiting for other threads to finish...')
+                    for thread in threads:
+                        thread.join()
+                    self._debug = True
+                    sys.exit(1)
                 if result is False:
                     # No image suitable for OCR.
                     pass
@@ -436,6 +451,9 @@ class Context(djvu.decode.Context):
                 pages_to_save = [page.n for page in pages]
             self._options.saver.save(document, pages_to_save, path, sed_file)
             document = None
+        except:
+            stop_threads()
+            raise
         finally:
             sed_file.close()
 
@@ -460,9 +478,11 @@ def main(argv=sys.argv):
     context.init(options)
     try:
         context.process(options.path, options.pages)
+    except KeyboardInterrupt:
+        logger.info('Interrupted by user.')
     finally:
         temp_dir = context.close()
         if temp_dir is not None:
-            print >>sys.stderr, 'Intermediate files were left in the %r directory.' % temp_dir
+            logger.info('Intermediate files were left in the %r directory.' % temp_dir)
 
 # vim:ts=4 sw=4 et
