@@ -1,11 +1,12 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
@@ -20,10 +21,12 @@ http://docs.google.com/Doc?id=dfxcv4vc_67g844kf
 import functools
 import re
 
+from . import utils
+
 try:
     from lxml import etree
 except ImportError, ex:
-    ex.args = '%s; please install the lxml package <http://codespeak.net/lxml/>' % str(ex),
+    utils.enhance_import_error(ex, 'lxml', 'python-lxml', 'http://codespeak.net/lxml/')
     raise
 
 from . import errors
@@ -254,7 +257,7 @@ def _scan(node, settings):
             return [result]
         else:
             # Should not happen.
-            assert 0 
+            assert 0
 
     if not has_zone:
         assert has_string
@@ -296,7 +299,7 @@ def _scan(node, settings):
             return []
 
     assert len(children) > 0
-    
+
     if not bbox:
         if len(node) == 0:
             # Ocropus 0.2 doesn't always provide necessary bounding box
