@@ -1,20 +1,33 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009, 2010 Jakub Wilk <jwilk@jwilk.net>
+
+# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
 import functools
 import locale
+import os
 import re
 import warnings
 
+debian = os.path.isdir('/var/lib/dpkg/info/')
+
+def enhance_import_error(exception, package, debian_package, homepage):
+    message = str(exception)
+    format = '%(message)s; please install the %(package)s package'
+    if debian:
+        package = debian_package
+    else:
+        format += ' <%(homepage)s>'
+    exception.args = [format % locals()]
+
 def parse_page_numbers(pages):
     '''
     parse_page_numbers(None) -> None
