@@ -1,11 +1,12 @@
 # encoding=UTF-8
+
 # Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
@@ -72,7 +73,8 @@ def _test_from_file(base_filename, index):
             try:
                 with open(os.devnull, 'w') as null:
                     with interim(sys, stdout=xmllint.stdin, stderr=null):
-                        rc = try_run(djvu2hocr.main, args)
+                        with interim(djvu2hocr.logger, handlers=[]):
+                            rc = try_run(djvu2hocr.main, args)
             finally:
                 xmllint.stdin.close()
                 try:
