@@ -1,11 +1,12 @@
 # encoding=UTF-8
+
 # Copyright © 2010 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 #
-# This package is distributed in the hope that it will be useful, but
+# This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
@@ -140,6 +141,8 @@ class test_environment():
             elif key == 'LANG':
                 has_lang = 1
                 assert_equal(value, '')
+            elif key == 'LANGUAGE':
+                assert_equal(value, '')
             else:
                 assert_equal(value, '"POSIX"')
         assert_true(has_lc_all)
